/*____________________________________________________________________________*\
 *

 Copyright (c) 1997 John Roy. All rights reserved.

 These sources, libraries and applications are
 FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
 as long as the following conditions are adhered to.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer. 

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

 3. Redistributions of any form whatsoever and all advertising materials 
    mentioning features must contain the following
    acknowledgment:
    "This product includes software developed by John Roy
    (http://www.johnroy.com/pi3/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHORS OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 OF THE POSSIBILITY OF SUCH DAMAGE.

 *____________________________________________________________________________*|
 *
 * $Source: PILog.h$
 * $Date: Sun Aug 10 06:42:18 1997$
 *
 Description:
\*____________________________________________________________________________*/
/* $HeaderTop:$ */

#ifndef PILOG_H_
#define PILOG_H_

#include "Pi2API.h"

/*____________________________________________________________________________*\
 *
 Description:
\*____________________________________________________________________________*/
/* --- error types --- */
#define	PILOG_ERROR		1	
#define	PILOG_WARNING	2
#define PILOG_ALL		3

/* --- sink types --- */
#define PILOG_DB		0
#define PILOG_FILE		1
#define PILOG_STDOUT	2
#define PILOG_STDERR	3

/*____________________________________________________________________________*\
 *
 Name:
	PILog_addMessage

 Synopsis:
	int PILog_addMessage( PIDB *pDB, PIConfig *pConfig, int iType,
		const char *pFormat, ... );
	
 Description:
	Log a message concerning initialization from a configuration file. 
	PILog_addMessage() will automatically include information from
	parsed configuration DB pConfig.

	pFormat is a printf() compatible format string. PILog_addMessage()
	takes a variable number of arguments. The number and type of
	arguments should be compatible with printf() directives.

	The flag iType indicates whether the item should be logged as an
	error or a warning, it may contain one of the following values:-
		PILOG_ERROR	
		PILOG_WARNING
		PILOG_ALL

 Notes:
	PILog_addMessage() looks under the root DB for a DB with a key of 
	PIDBKEY_DIAGNOSTICS.

 Return Values:
	On success PILog_addMessage() returns zero (PIAPI_COMPLETED).

 Errors:
	PIAPI_EINVAL	if pDB or pFormat is NULL.
	PIAPI_ERROR		if another error occurred.

 See Also:
\*____________________________________________________________________________*/
PUBLIC_PIAPI int PILog_addMessage( PIDB *pDB, PIConfig *pConfig, int iType,
	const char *pFormat, ... );

/*____________________________________________________________________________*\
 *
 Name:
	PILog_writeDiagnostics

 Synopsis:
	int PILog_writeDiagnostics( PIDB *pDB, int iFlags, const char *pFileName )
	
 Description:
	Write the contents of the diagnostics DB to the file pFileName. The
	value iFlags is the inclusive-or of diagnostic types to write,  the
	macro PILOG_ALL can be used to specify all message types.

	If pFileName is NULL the output will be written to the standard output.

 Notes:
	PILog_writeDiagnostics() looks under the root DB for a DB with a key of 
	PIDBKEY_DIAGNOSTICS.

 Return Values:
	On success PILog_writeDiagnostics() returns zero (PIAPI_COMPLETED).

 Errors:
	PIAPI_EINVAL	if pDB is NULL.
	PIAPI_ERROR		if another error occurred.

 See Also:
\*____________________________________________________________________________*/
PUBLIC_PIAPI int PILog_writeDiagnostics( PIDB *pDB, int iFlags, 
	const char *pFileName );

/*____________________________________________________________________________*\
 *
 Name:
	PILog_newSink

 Synopsis:
	int PILog_newSink( int iType, const char *pParam )
	
 Description:
	Sets a new sink for logged messages. Messages can be sent to the
	main program DB (default), to a file (path to file is given by parameter
	pParam), or to a standard stream.

	The following flags for iType dictate the new sink.

<UL>
<ITEM><B>PILOG_DB</B>	 - main program DB, under subtree 'Diagnostics'.
<ITEM><B>PILOG_FILE</B>	 - a file, path is specified by parameter pParam.
<ITEM><B>PILOG_STDOUT</B> - the stdout stream.
<ITEM><B>PILOG_STDERR</B> - the stderr stream.
</UL>

 Notes:
	Current logging to a file via this mechanism is not implemented,	
	attempting to set the log sink to a file will result in an error
	code of PIAPI_NOTSUPPORTED.

 Return Values:
	On success PILog_newSink() returns zero (PIAPI_COMPLETED).

 Errors:
	PIAPI_EINVAL	if iType is PILOG_FILE and pParam is NULL.
	PIAPI_ERROR		if another error occurred.
	PIAPI_NOTSUPPRTED as described under notes.

 See Also:
\*____________________________________________________________________________*/
PUBLIC_PIAPI int PILog_newSink( int iType, const char *pParam );

#endif	/* PILOG_H_ */

